<?php
	//// Exemple d'éxécution de requête, à faire pour chaque requête
	// Simplement : Je passe un numéro de commande à la fonction
	// Elle effectue une requête SQL pour la récupérer, 3 résultats possibles
	// - Commande trouvée, elle est renvoyée sous forme de tableau associatif
	// - Commande non trouvée, un tableau vide est renvoyé
	// - Erreur php/sql, l'erreur est affichée, false est renvoyé



	// Je met l'ensemble dans une fonction, afin que la requête
	// ne soit préparée qu'en cas de besoin

	//					  On passe en paramètre (depuis l'extérieur de la fonction)
	//					  ce dont on a besoin
	function getOneOrder( $orderNumber ) {

		// Je réutilise la variable $pdo définie dans php/_connexion.php,
		// lui même inclus sur l'ensemble des pages dans header.php
		global $pdo;

		// Exemple de requête SQL basique, avec préparation
		// http://php.net/manual/fr/pdo.prepared-statements.php
		$stmt = $pdo->prepare("
		
			SELECT *
			FROM orders
			WHERE orderNumber = :orderNumber"
		
		);
		
		// De cette manière, on est certain de ne pas ajouter de code malicieux dans le SQL
		// :orderNumber sera remplacé par sa valeur 'assainie'
		$stmt->bindParam(':orderNumber', $reqOrderNumber);
		

		// On ajoute un try/catch afin d'intercepter les éventuelles erreurs PHP
		// lors de l'éxécution de la requête.
		// Cela évite que php 'plante' le programme en affichant l'erreur,
		// puis en appelant la fonction die() qui stope l'affichage de la page
		try {

			// Définition des variables à passer dans le SQL de manière saine
			//				  Cette variable est définie dans php/controller_index.php
			//				  lors de l'appel de la fonction
			$reqOrderNumber = $orderNumber;

			// Execution du sql
			$stmt->execute();
			

			// Création de la variable à renvoyer
			// afin de permettre de récupérer les résultats en dehors de la fonction
			$retourRequete = []; // tableau vide

			// Récupération des données ligne par ligne
			// while ($ligneSQL = $stmt->fetch()) {
			// 	// Chaque ligne SQL renvoyée par la base de donnée est stockée dans une nouvelle case de mon tableau de retour.
			// 	$retourREQUETEORDERS[] = $ligneSQL;
			// }
			
			// Récupération du tableau complet directement
			// Si la commande n'existe pas en bdd, la fonction renverra un tableau vide
			// Note : Cela permet de différencier l'absence de résultats d'une erreur PHP (ligne ~90)
			$retourRequete = $stmt->fetchAll();

			// Si la commande a bien été trouvée, on la renvoie, elle uniquement
			if( sizeof($retourRequete) > 0 ) {
				$retourRequete = $retourRequete[0];
			}
			
			// Renvoi du résultat à l'extérieur de la fonction
			return $retourRequete;
		}
		// Si une erreur est interceptée (syntaxe ou )
		catch (PDOException $e) {
			
			// On l'affiche correctement pour l'utilisateur

			//// Affichage plus classique PHP
			// var_dump($e);
			// echo "<table class=\"xdebug-error\">";
			// echo 	$e->xdebug_message;
			// echo "</table><br/>";

			// Affichage personnalisé
			// http://php.net/manual/fr/pdo.errorinfo.php
			
			$errorInfo = $stmt->errorInfo();
			// var_dump($errorInfo);
			
				// Affiche du message d'erreur uniquement
			echo "	<div class=\"sqlError\">
						<fieldset>
							<legend>Erreur sql ¯\_(ツ)_/¯</legend>
							<div class=\"content\">" . $errorInfo[2] . "</div>
						</fieldset>
					</div>
			";

			// On renvoie faux afin de pouvoir gérer l'erreur lors de l'affichage
			return false;
		}
	}
?>